package org.verohallinto.apitamoclient.ui;

import org.apache.pivot.collections.ArrayList;
import org.apache.pivot.collections.Sequence;
import org.apache.pivot.util.Filter;
import org.apache.pivot.wtk.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;

/**
 * Retrieval tab.
 */
public class TabRetrieve {

    private static final Logger log = LoggerFactory.getLogger(TabRetrieve.class);

    /**
     * Constuctor.
     * </p>
     *
     * @param ui <code>ApitamopkiClientUI</code>
     */
    public TabRetrieve(final ApitamopkiClientUI ui) {

        // Aineiston / tarkastustuloksen nouto
        ui.retrBG.getButtonGroupListeners().add(new ButtonGroupListener.Adapter() {
            @Override
            public void selectionChanged(final ButtonGroup bg, final Button previousSelection) {
                super.selectionChanged(bg, previousSelection);

                final Button button = bg.getSelection();
                final String data = (String)button.getButtonData();

                if (data.startsWith("Aineiston")) {
                    ui.retrId.setPrompt("Anna aineiston noutotunniste");
                } else {
                    ui.retrId.setPrompt("Anna tarkastustuloksen noutotunniste");
                }
            }
        });

        // Ilmoitusten kieli
        ui.retrLanguageBG.getButtonGroupListeners().add(new ButtonGroupListener.Adapter() {
            @Override
            public void selectionChanged(final ButtonGroup bg, final Button previousSelection) {
                super.selectionChanged(bg, previousSelection);

                final Button button = bg.getSelection();
                final Object data = button.getButtonData();

                for (Button lang : ui.sendLanguageBG) {
                    if (lang.getButtonData().equals(data)) {
                        lang.setSelected(true);
                        break;
                    }
                }
            }
        });

        // Palautettavan aineiston ja tarkastustuloksen hakemiston poiminta
        ui.retrBrowser = new FileBrowserSheet();
        ui.retrBrowser.setMode(FileBrowserSheet.Mode.SAVE_TO);
        ui.retrBrowser.setRootDirectory(ui.workDir);
        ui.retrBrowser.setDisabledFileFilter(new Filter<File>() {
            @Override
            public boolean include(final File item) {

                return !(item.isDirectory());
            }
        });

        // Noudettava ainesto
        ui.retrResult.setText(ui.workDir.getAbsolutePath());

        // Noudetun aineiston tai tarkastustuloksen hakemiston pominta
        ui.retrResultPB.getButtonPressListeners().add(new ButtonPressListener() {
            @Override
            public void buttonPressed(final Button button) {

                ui.retrBrowser.open(ui, new SheetCloseListener() {
                    @Override
                    public void sheetClosed(final Sheet sheet) {

                        if (sheet.getResult()) {
                            final Sequence<File> selectedFiles = ui.retrBrowser.getSelectedFiles();
                            final ListView listView = new ListView();
                            listView.setListData(new ArrayList<>(selectedFiles));
                            ui.retrResult.setText(selectedFiles.get(0).getAbsolutePath());
                        }
                    }
                });
            }
        });

        // Aineiston tai tarkastustuloksen nouto
        ui.retrPB.getButtonPressListeners().add(new ButtonPressListener() {
            @Override
            public void buttonPressed(final Button button) {

                // Poistetaan ID:n mahdolliset roskat
                ui.retrId.setText(ui.retrId.getText().trim());
                //
                ui.resLeft.setText("");
                ui.resRight.setText("");
                ui.status.setText("");
                ui.status.repaint(true);
                ui.retrPB.setEnabled(false);
                ui.retrPB.repaint(true);

                try {
                    ui.action.retrievalOperation();
                } catch (Exception e) {
                    ui.action.handleException(e);
                }

                ui.retrPB.setEnabled(true);
                ui.retrPB.repaint(true);
            }
        });
    }
}
